@@ -6,7 +6,8 @@ namespace Lcobucci\Clock;
 use DateMalformedStringException;
 use DateTimeImmutable;
 use DateTimeZone;
-use InvalidArgumentException;
+
+use function date_default_timezone_get;
 
 final class FrozenClock implements Clock
 {
@@ -19,6 +20,11 @@ final class FrozenClock implements Clock
         return new self(new DateTimeImmutable('now', new DateTimeZone('UTC')));
     }
 
+    public static function fromSystemTimezone(): self
+    {
+        return new self(new DateTimeImmutable('now', new DateTimeZone(date_default_timezone_get())));
+    }
+
     public function setTo(DateTimeImmutable $now): void
     {
         $this->now = $now;
@@ -27,21 +33,13 @@ final class FrozenClock implements Clock
     /**
      * Adjusts the current time by a given modifier.
      *
-     * @param string $modifier @see https://www.php.net/manual/en/datetime.formats.php
+     * @param non-empty-string $modifier @see https://www.php.net/manual/en/datetime.formats.php
      *
-     * @throws InvalidArgumentException When an invalid format string is passed (PHP < 8.3).
-     * @throws DateMalformedStringException When an invalid date/time string is passed (PHP 8.3+).
+     * @throws DateMalformedStringException When an invalid date/time string is passed.
      */
     public function adjustTime(string $modifier): void
     {
-        $modifiedTime = @$this->now->modify($modifier);
-
-        // PHP < 8.3 won't throw exceptions on invalid modifiers
-        if ($modifiedTime === false) {
-            throw new InvalidArgumentException('The given modifier is invalid');
-        }
-
-        $this->now = $modifiedTime;
+        $this->now = $this->now->modify($modifier);
     }
 
     public function now(): DateTimeImmutable
